@@ -1,5 +1,31 @@
 from __future__ import absolute_import, division, print_function
 
+__copyright__ = """
+Copyright (C) 2009-2017 Andreas Kloeckner
+Copyright (C) 2014-2017 Aaron Meurer
+"""
+
+__license__ = """
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+THE SOFTWARE.
+"""
+
+
 import os
 import sys
 
@@ -58,7 +84,7 @@ def load_config():
 
         if cparser.has_section(CONF_SECTION):
             conf_dict.update(dict(cparser.items(CONF_SECTION)))
-    except:
+    except Exception:
         pass
 
     conf_dict.setdefault("shell", "internal")
@@ -91,7 +117,7 @@ def load_config():
                 conf_dict[name] = False
             else:
                 conf_dict[name] = True
-        except:
+        except Exception:
             pass
 
     normalize_bool_inplace("line_numbers")
@@ -117,7 +143,7 @@ def save_config(conf_dict):
         outf = open(join(save_path, CONF_FILE_NAME), "w")
         cparser.write(outf)
         outf.close()
-    except:
+    except Exception:
         pass
 
 
